Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2543)

Unified Diff: chrome/browser/media_gallery/media_galleries_dialog_controller.h

Issue 11138010: Remove TabContents from media galleries. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/media_gallery/media_galleries_dialog_controller.h
diff --git a/chrome/browser/media_gallery/media_galleries_dialog_controller.h b/chrome/browser/media_gallery/media_galleries_dialog_controller.h
index 9a17db03b0b540cc649ee450a7d5c0655998e30e..9ad393cec30e755d7c1424310714256ec63acf69 100644
--- a/chrome/browser/media_gallery/media_galleries_dialog_controller.h
+++ b/chrome/browser/media_gallery/media_galleries_dialog_controller.h
@@ -15,12 +15,14 @@
#include "ui/base/dialogs/select_file_dialog.h"
#include "ui/gfx/native_widget_types.h"
+namespace content {
+class WebContents;
+}
+
namespace extensions {
class Extension;
}
-class TabContents;
-
namespace chrome {
class MediaGalleriesDialogController;
@@ -61,7 +63,7 @@ class MediaGalleriesDialogController : public ui::SelectFileDialog::Listener {
KnownGalleryPermissions;
// The constructor creates a dialog controller which owns itself.
- MediaGalleriesDialogController(TabContents* tab_contents,
+ MediaGalleriesDialogController(content::WebContents* web_contents,
const extensions::Extension& extension,
const base::Closure& on_finish);
@@ -79,8 +81,8 @@ class MediaGalleriesDialogController : public ui::SelectFileDialog::Listener {
virtual void FileSelected(const FilePath& path,
int index,
void* params) OVERRIDE;
- TabContents* tab_contents() const {
- return tab_contents_;
+ content::WebContents* web_contents() const {
+ return web_contents_;
}
protected:
@@ -102,8 +104,8 @@ class MediaGalleriesDialogController : public ui::SelectFileDialog::Listener {
// Saves state of |known_galleries_| and |new_galleries_| to model.
void SavePermissions();
- // The tab contents from which the request originated.
- TabContents* tab_contents_;
+ // The web contents from which the request originated.
+ content::WebContents* web_contents_;
// This is just a reference, but it's assumed that it won't become invalid
// while the dialog is showing. Will be NULL only during tests.

Powered by Google App Engine
This is Rietveld 408576698